package com.ruoyi.cs.service;

import java.util.List;
import com.ruoyi.cs.domain.CsResourceClass;

/**
 * 资源分类Service接口
 *
 * @author ruoyi
 * @date 2024-04-22
 */
public interface ICsResourceClassService
{
    /**
     * 查询资源分类
     *
     * @param resourceClassId 资源分类主键
     * @return 资源分类
     */
    public CsResourceClass selectCsResourceClassByResourceClassId(String resourceClassId);

    /**
     * 查询资源分类列表
     *
     * @param csResourceClass 资源分类
     * @return 资源分类集合
     */
    public List<CsResourceClass> selectCsResourceClassList(CsResourceClass csResourceClass);

    /**
     * 新增资源分类
     *
     * @param csResourceClass 资源分类
     * @return 结果
     */
    public int insertCsResourceClass(CsResourceClass csResourceClass);

    /**
     * 修改资源分类
     *
     * @param csResourceClass 资源分类
     * @return 结果
     */
    public int updateCsResourceClass(CsResourceClass csResourceClass);

    /**
     * 批量删除资源分类
     *
     * @param resourceClassIds 需要删除的资源分类主键集合
     * @return 结果
     */
    public int deleteCsResourceClassByResourceClassIds(String[] resourceClassIds);

    /**
     * 删除资源分类信息
     *
     * @param resourceClassId 资源分类主键
     * @return 结果
     */
    public int deleteCsResourceClassByResourceClassId(String resourceClassId);
}
